@@ -17,9 +17,9 @@ sudo apt install -y build-essential \
                     fonts-wine
 
 # Only needed if you are using the OS installed (packaged) Perl
-echo "OS prerequisites installed.  It is recommended you answer YES to the next question."
+echo "OS prerequisites installed.  Now for the Perl prerequisites."
+echo "It is recommended you answer YES to the next question:"
 
-read -p "Do you wish to install the packaged/system Perl module prerequisites?  " yn
 case $yn in
     [Yy]* ) 
         sudo apt install -y libimager-perl \
